#define BSD_COMP
#include <stdio.h>   /* Standard input/output definitions */
#include <string.h>  /* String function definitions */
#include <unistd.h>  /* UNIX standard function definitions */
#include <fcntl.h>   /* File control definitions */
#include <errno.h>   /* Error number definitions */
#include <termios.h> /* POSIX terminal control definitions */
//#include <asm/termios.h>
#define FIONREAD 0x541B 
//port is the device name ( eg /dev/ttyUSB0 )
//returns -1 on error
int OpenPort(const char * port)
{
	int port_handle;
	port_handle = open(port,O_RDWR | O_NOCTTY | O_NDELAY);
	if (port_handle == -1)
	{
		perror("Unable to open port");
	}
	else
	{
		fcntl(port_handle,F_SETFL,1);
	}
	return port_handle;
}

//closes a port opened with OpenPort
void ClosePort(const int port)
{
	if (port >= 0)
	{
		close(port);
	}
}

int WriteData(const char * data, unsigned long length, const int port)
{
	long n;
	printf("%x\n",(unsigned char)data[0]);
	n = write(port,data,length);
	if (n < 0)
	{
		perror("Write Port Failed");
		return 0;
	}
	return 1;
}


void SetupSSPPort(const int port)
{
	struct termios options;
	tcgetattr(port,&options);
	
	//9600 baud
	cfsetispeed(&options,B9600);
	cfsetospeed(&options,B9600);
	//no parity
	options.c_cflag &= ~PARENB;

	//2 stop bits
	options.c_cflag |= CSTOPB;
	//	options.c_cflag &= ~CSTOPB;
	
	//8 bits
	options.c_cflag &= ~CSIZE;
	options.c_cflag |= CS8;
		
	//raw binary input / output
	options.c_lflag &= ~(ICANON | ECHO | ECHOE | ISIG);
        options.c_oflag &= ~OPOST;
	
        //no flow control
	options.c_iflag &= ~(IXON | IXOFF | IXANY);
	options.c_cflag &= ~CRTSCTS;

	options.c_cflag |= (CLOCAL | CREAD);
        fcntl(port, F_SETFL, FNDELAY);	
	tcsetattr(port,TCSANOW,&options);
}

int BytesInBuffer(int port)
{
	int bytes;
	ioctl(port,FIONREAD,&bytes);
	return bytes;
}

int ReadData(const int port, unsigned char * buffer, unsigned long bytes_to_read)
{
	return read(port,buffer,bytes_to_read);
}
