typedef struct SSP_COMMAND
{
	unsigned char address;
	unsigned char data[256];
	unsigned char length;
} SSP_COMMAND;


//Standard BNV SSP Commands
#define SSP_CMD_RESET 0x1
#define SSP_CMD_SET_INHIBITS 0x2
#define SSP_CMD_BULB_ON 0x3
#define SSP_CMD_BULB_OFF 0x4
#define SSP_CMD_SETUP_REQUEST 0x5
#define SSP_CMD_HOST_PROTOCOL 0x6
#define SSP_CMD_POLL 0x7
#define SSP_CMD_REJECT_NOTE 0x8
#define SSP_CMD_DISABLE 0x9
#define SSP_CMD_ENABLE 0xA
#define SSP_CMD_PROGRAM 0xB //See SSP_PROGRAM_* defintions for second byte
#define SSP_CMD_SERIAL_NUMBER 0xC
#define SSP_CMD_UNIT_DATA 0xD
#define SSP_CMD_CHANNEL_VALUES 0xE
#define SSP_CMD_CHANNEL_SECURITY 0xF
#define SSP_CMD_CHANNEL_RETEACH 0x10
#define SSP_CMD_SYNC 0x11
#define SSP_CMD_DISPENSE 0x12
#define SSP_CMD_PROGRAM_STATUS 0x16
#define SSP_CMD_LAST_REJECT 0x17
#define SSP_CMD_HOLD 0x18
#define SSP_CMD_MANUFACTURER 0x30
#define SSP_CMD_EXPANSION 0x30


//generic SSP Responses
#define SSP_RESPONSE_OK 0xF0
#define SSP_RESPONSE_UNKNOWN_COMMAND 0xF2
#define SSP_RESPONSE_INCORRECT_PARAMETERS 0xF3
#define SSP_RESPONSE_INVALID_PARAMETER 0xF4
#define SSP_RESPONSE_COMMAND_NOT_PROCESSED 0xF5
#define SSP_RESPONSE_SOFTWARE_ERROR 0xF6
#define SSP_RESPONSE_CHECKSUM_ERROR 0xF7
#define SSP_RESPONSE_FAILURE 0xF8
#define SSP_RESPONSE_HEADER_FAILURE 0xF9


//Poll Responses
#define SSP_POLL_RESET 0xF1
#define SSP_POLL_READ 0xEF //next byte is channel (0 for unknown)
#define SSP_POLL_CREDIT 0xEE //next byte is channel
#define SSP_POLL_REJECTING 0xED
#define SSP_POLL_REJECTED 0xEC
#define SSP_POLL_STACKING 0xCC
#define SSP_POLL_STACKED 0xEB
#define SSP_POLL_SAFE_JAM 0xEA
#define SSP_POLL_UNSAFE_JAM 0xE9
#define SSP_POLL_DISABLED 0xE8
#define SSP_POLL_FRAUD_ATTEMP 0xE6 //next byte is channel
#define SSP_POLL_STACKER_FULL 0xE7

//Programming Type
#define SSP_PROGRAM_FIRMWARE 0x0
#define SSP_PROGRAM_DATASET 0x1

//channel definitions
#define SSP_CHANNEL_ONE 0x1
#define SSP_CHANNEL_TWO 0x2
#define SSP_CHANNEL_THREE 0x3
#define SSP_CHANNEL_FOUR 0x4
#define SSP_CHANNEL_FIVE 0x5
#define SSP_CHANNEL_SIX 0x6
#define SSP_CHANNEL_SEVEN 0x7
#define SSP_CHANNEL_EIGHT 0x8
#define SSP_CHANNEL_NINE 0x9
#define SSP_CHANNEL_TEN 0xA
#define SSP_CHANNEL_ELEVEN 0xB
#define SSP_CHANNEL_TWELVE 0xC
#define SSP_CHANNEL_THIRTEEN 0xD
#define SSP_CHANNEL_FOURTEEN 0xE
#define SSP_CHANNEL_FIFTEEN 0xF
#define SSP_CHANNEL_SIXTEEN 0x10
